from typing import Dict, Set

from sziszapangma.integration.path_filter import PathFilter
from sziszapangma.integration.record_id_iterator import RecordIdIterator
from sziszapangma.integration.record_path_provider import RecordPathProvider
from sziszapangma.integration.relation_manager_provider import RelationManagerProvider
from sziszapangma.model.relation_manager import RelationManager, FileRelationManager


class LunaRecordProvider(RecordIdIterator, RecordPathProvider, RelationManagerProvider):
    _path_by_id: Dict[str, str]

    def __init__(self, path_filter: PathFilter):
        self._path_by_id = dict({
            self._get_id(it): it
            for it in path_filter.get_list_of_files()
        })

    def get_all_records(self) -> Set[str]:
        return set(self._path_by_id.keys())

    def get_path(self, record_id: str) -> str:
        return self._path_by_id[record_id]

    def get_item_file_path(self, record_id: str, file) -> str:
        return self._path_by_id[record_id]

    def get_relation_manager(self, record_id: str) -> RelationManager:
        basic_path = self.get_path(record_id)[:-4]
        return FileRelationManager(f'{basic_path}_ab_relations.csv', f'{basic_path}_ab_items.json')

    @staticmethod
    def _get_id(record_file_path: str) -> str:
        path = record_file_path.replace('.wav', '')
        return '/'.join(path.split('/')[-6:])
